##  MAPPING_TABLE
The MAPPING_TABLE configuration defines the case when a custom table which holds two columns of field type Reference in ServiceNow are used to hold relations between two items in arbitrary tables.
This case is analogous to a mapping table concept as used in databases.
For this relation mapping, please select the table and fields you want to read the relation from.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2753075f7a4410149aba846cf00dbb40_LowRes.png)
